@@ -15,24 +15,26 @@
 ##' Binomial Population sensitivity
 ##' @description Calculates population sensitivity for detecting disease,
 ##'   assuming imperfect test sensitivity and specificity and representative sampling,
-##'   using binomial distribution (assumes large or unknown population size and that 
-##'   cut-point number of reactors for a positive result = 1) 
-##' @param n sample size = number of units tested (integer), scalar or vector  
+##'   using binomial distribution (assumes large or unknown population size and that
+##'   cut-point number of reactors for a positive result = 1)
+##' @param n sample size = number of units tested (integer), scalar or vector
 ##' @param pstar design prevalence as a proportion (scalar or vector of same length as n)
 ##' @param se unit sensitivity of test (proportion), default = 1 (scalar or vector of same length as n)
 ##' @param sp unit specificity of test (proportion), default = 1 (scalar or vector of same length as n)
+##' @param dig number of digits for rounding of results
 ##' @return vector of population-level sensitivities
 ##' @keywords methods
+##' @include freedom_functions_1.R
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for sep.binom - checked
 ##' sep.binom(n=300, pstar = 0.02, se = 0.92)
 ##' tested<- seq(10,100, by=10)
 ##' prev<- 0.05
 ##' sens<- 0.9
 ##' sep.binom(tested, prev, sens)
-sep.binom<- function(n, pstar, se = 1, sp = 1) {
-    sep<- 1 - (1 - (se*pstar+(1-sp)*(1-pstar)))^n
+sep.binom<- function(n, pstar, se = 1, sp = 1, dig = 5) {
+    sep<- round(1 - (1 - (se*pstar+(1-sp)*(1-pstar)))^n, dig)
     return(sep)
 } # end of sep.binom
 
@@ -43,36 +45,39 @@ sep.binom<- function(n, pstar, se = 1, sp = 1) {
 ##' @param se unit sensitivity of test (proportion), scalar or vector
 ##' @param d expected number of infected units in population (=design prevalence*N
 ##'   rounded to next integer), scalar or vector of same length as se
+##' @param dig number of digits for rounding of results
 ##' @return vector of population-level sensitivities
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for sep.exact - checked
 ##' sep.exact(d=1, se = 0.92)
 ##' inf<- 1:5
 ##' sens<- 0.8
 ##' sep.exact(d=inf, se=sens)
 ##' sep.exact(se=0.8, d = ceiling(0.01*c(10, 50, 100, 250, 500)))
-sep.exact<- function(d=1, se = 1) {
-  sep<- 1 - (1 - se)^d
+sep.exact<- function(d=1, se = 1, dig = 5) {
+  sep<- round(1 - (1 - se)^d, dig)
     return(sep)
 } # end of sep.exact
 
 
 ##' Hypergeometric Population sensitivity
 ##' @description Calculates population sensitivity for detecting disease,
-##'   assuming imperfect test sensitivity, perfect test specificity 
+##'   assuming imperfect test sensitivity, perfect test specificity
 ##'   and representative sampling,
-##'   using hypergeometric approximation (assumes known population size) 
+##'   using hypergeometric approximation (assumes known population size)
 ##' @param N population size, scalar or vector of same length as n
 ##' @param n sample size (number tested), scalar or vector
-##' @param d expected number of infected units in population (=design prevalence*N 
+##' @param d expected number of infected units in population (=design prevalence*N
 ##'   rounded to next integer)
 ##' @param se unit sensitivity of test (proportion), scalar or vector of same length as n
-##' @return a vector of population-level sensitivities
+##' @param dig number of digits for rounding of results
+##' @return a vector of population-level sensitivities. if all n <= corresponding N then 
+##' vector is numeric, otherwise vector is character and elements where n>N are recorded as such
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for sep.hypergeo - checked
 ##' sep.hypergeo(N=100, n=50, d=1, se = 0.92)
 ##' inf<- 1:5
@@ -80,20 +85,23 @@ sep.exact<- function(d=1, se = 1) {
 ##' sep.hypergeo(N=100, n=50, d=inf, se=sens)
 ##' N<- c(10, 50, 100, 250, 500)
 ##' sep.hypergeo(se=0.8, N=N, n=c(5, 25, 50, 125, 250), d = ceiling(0.01*N))
-sep.hypergeo<- function(N, n, d, se = 1) {
-  sep<- 1 - (1 - se*n/N)^d
+sep.hypergeo<- function(N, n, d, se = 1, dig = 5) {
+  d<- pmin(N, d)
+  sep<- round(1 - (1 - se*n/N)^d, dig)
+  sep[n == 0]<- 0
+  sep[n>N]<- NA
     return(sep)
 } # end of sep.hypergeo
 
 
 ##' Population specificity
 ##' @description Calculates population specificity assuming representative sampling
-##' @param n sample size (number tested), integer, scalar or vector  
+##' @param n sample size (number tested), integer, scalar or vector
 ##' @param sp unit specificity of test (proportion), scalar or vector of same length as n
 ##' @return a vector of population-level specificities
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for spp - checked
 ##' spp(10, 0.9)
 ##' spp(c(10, 20, 50, 100), 0.99)
@@ -104,20 +112,21 @@ spp<- function(n, sp) {
 } # end of spp function
 
 
-##' Population sensitivity 
+##' Population sensitivity
 ##' @description Calculates population sensitivity using appropriate method,
-##'   depending on whether or not N provided (hypergeometric if N provided, 
-##'   binomial otherwise), assuming perfect 
+##'   depending on whether or not N provided (hypergeometric if N provided,
+##'   binomial otherwise), assuming perfect
 ##'   test specificity and representative sampling
 ##' @param N population size, NA or vector of same length as n
 ##' @param n sample size (number tested), scalar or vector
 ##' @param pstar design prevalence as a proportion or integer, scalar
 ##'   or vector of same length as n
 ##' @param se unit sensitivity, scalar or vector of same length as n
+##' @param dig number of digits for rounding of results
 ##' @return a vector of population-level sensitivities
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for sep - checked
 ##' sep(n=300, pstar=0.01, se=1)
 ##' sep(NA, 300, 0.01, 1)
@@ -132,21 +141,15 @@ spp<- function(n, sp) {
 ##' N<- c(55, 134, NA, 44, 256)
 ##' n<- c(15, 30, 28, 15, 33)
 ##' sep(N, n, 0.1, 0.95)
-sep<- function(N = NA, n, pstar, se=1) {
+sep<- function(N = NA, n, pstar, se=1, dig = 5) {
   # check for errors in inputs
   # pstar.int = flag to indicate proportion (F) or integer (T) design prevalence
   pstar.int<- !(pstar < 1 & pstar > 0)
   if (sum(is.na(N)) > 0 & pstar.int) {
     err.msg<- "Population size (N) must be provided if design prevalence is an integer."
     return(err.msg)
-  } else if (sum(n[!is.na(N)] > N[!is.na(N)]) > 0) {
-    err.msg<- "Sample size (n) cannot be greater than population size (N)."
-    return(err.msg)
   } else if (pstar.int & (pstar < 1 | pstar != round(pstar, 0))) {
-    err.msg<- "Design prevalence must be an integer >= 1 if it is specified as an integer."
-    return(err.msg)
-  } else if (!pstar.int & (pstar >= 1 | pstar <= 0)) {
-    err.msg<- "Design prevalence must be >0 and <1 if it is specified as a proportion."
+    err.msg<- "Design prevalence must be a proportion OR a positive integer."
     return(err.msg)
   }
   # sep calculations
@@ -155,13 +158,12 @@ sep<- function(N = NA, n, pstar, se=1) {
   if (length(se) == 1) se<- rep(se, length(n))
   d<- pstar
   if (length(d) == 1) d<- rep(d, length(n))
-  if (length(sep[is.na(N)]) >0) sep[is.na(N)]<- sep.binom(n=n[is.na(N)], pstar=pstar, se=se[is.na(N)])
+  if (length(sep[is.na(N)]) >0) sep[is.na(N)]<- sep.binom(n=n[is.na(N)], pstar=pstar, se=se[is.na(N)], dig=dig)
   if (sum(!is.na(N)) != 0) {
     if (!pstar.int) {
       d[!is.na(N)]<- ceiling(N[!is.na(N)] * pstar)
     }
-    sep[N == n & !is.na(N)]<- sep.exact(d=d[N == n & !is.na(N)], se=se[N == n & !is.na(N)])
-    sep[N != n & !is.na(N)]<- sep.hypergeo(N=N[N != n & !is.na(N)], n=n[N != n & !is.na(N)], d=d[N != n & !is.na(N)], se=se[N != n & !is.na(N)])
+    sep[!is.na(N)]<- sep.hypergeo(N=N[!is.na(N)], n=n[!is.na(N)], d=d[!is.na(N)], se=se[!is.na(N)], dig)
 
   }
   return(sep)
@@ -169,18 +171,18 @@ sep<- function(N = NA, n, pstar, se=1) {
 
 
 ##' Population sensitivity for varying unit sensitivity
-##' @description Calculates population-level sensitivity where unit sensitivity 
-##'   varies and using the appropriate method, depending on whether or not N provided 
-##'   (hypergeometric if N provided, binomial otherwise), assuming perfect 
+##' @description Calculates population-level sensitivity where unit sensitivity
+##'   varies and using the appropriate method, depending on whether or not N provided
+##'   (hypergeometric if N provided, binomial otherwise), assuming perfect
 ##'   test specificity and representative sampling
-##' @param N population size (number of units or clusters), N must be >= length(se)) 
+##' @param N population size (number of units or clusters), N must be >= length(se))
 ##'   or NA if unknown
 ##' @param se vector of unit sensitivity values (proportion) for each unit sampled
 ##' @param pstar specified design prevalence (scalar)
 ##' @return a scalar of population-level sensitivity
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples of sep.var.se - checked
 ##' sens<- c(rep(0.9, 50), rep(0.95, 100))
 ##' sep.var.se(NA, sens, 0.01)
@@ -200,10 +202,10 @@ sep.var.se<- function(N=NA, se, pstar) {
 }
 
 
-##' 2-stage population sensitivity 
+##' 2-stage population sensitivity
 ##' @description Calculates population-level (system) sensitivity for representative
-##'   2-stage sampling (sampling of clusters and units within clusters), 
-##'   assuming imperfect test sensitivity and perfect test specificity 
+##'   2-stage sampling (sampling of clusters and units within clusters),
+##'   assuming imperfect test sensitivity and perfect test specificity
 ##' @param H population size = number of clusters in the population, default = NA
 ##' @param N population size within clusters,
 ##'   scalar or a vector of same length as n, default = NA
@@ -213,14 +215,14 @@ sep.var.se<- function(N=NA, se, pstar) {
 ##'   either proportion or integer
 ##' @param pstar.u unit (animal) level design prevalence, scalar,
 ##'   either proportion or integer
-##' @return list of 6 elements, 1) population level sensitivity, 2) vector of 
-##'   cluster-level sensitivities, 3) N, 4) n, 5) vector of design prevalences 
-##'   and 6) unit sensitivity 
-##' @note if pstar.c is not a proportion N must be provided 
+##' @return list of 6 elements, 1) population level sensitivity, 2) vector of
+##'   cluster-level sensitivities, 3) N, 4) n, 5) vector of design prevalences
+##'   and 6) unit sensitivity
+##' @note if pstar.c is not a proportion N must be provided
 ##'   (and N>=n)
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for sep.sys - checked
 ##' H<- 500
 ##' N<- rep(1000, 150)
@@ -252,7 +254,7 @@ sep.sys<- function(H=NA, N=NA, n, pstar.c, pstar.u, se=1) {
 ###########################################################################
 # Sample size calculations
 ###########################################################################
-# calculate sample size assuming sampling with (binomial) or 
+# calculate sample size assuming sampling with (binomial) or
 # without (hypergeometric) replacement
 # n.binom
 # n.hypergeo
@@ -260,8 +262,8 @@ sep.sys<- function(H=NA, N=NA, n, pstar.c, pstar.u, se=1) {
 # n.2stage
 
 ##' Binomial sample size
-##'@description Calculates sample size for demonstrating freedom or 
-##'   detecting disease using binomial approach and assuming 
+##'@description Calculates sample size for demonstrating freedom or
+##'   detecting disease using binomial approach and assuming
 ##'   imperfect test sensitivity, perfect test specificity and
 ##'   representative sampling
 ##' @param sep desired population sensitivity (scalar or vector)
@@ -270,7 +272,7 @@ sep.sys<- function(H=NA, N=NA, n, pstar.c, pstar.u, se=1) {
 ##' @return vector of sample sizes
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for n.binom - checked
 ##' n.binom(sep=0.95, pstar=c(0.01, 0.02, 0.05, 0.1, 0.2))
 ##' n.binom(c(0.5, 0.8, 0.9, 0.95), 0.01)
@@ -281,8 +283,8 @@ n.binom<- function(sep, pstar, se = 1) {
 
 
 ##' Hypergeometric sample size
-##'@description Calculates sample size for demonstrating freedom or 
-##'   detecting disease using hypergeometric approximation and assuming 
+##'@description Calculates sample size for demonstrating freedom or
+##'   detecting disease using hypergeometric approximation and assuming
 ##'   imperfect test sensitivity, perfect test specificity and
 ##'   representative sampling
 ##' @param sep desired population sensitivity (scalar or vector)
@@ -293,7 +295,7 @@ n.binom<- function(sep, pstar, se = 1) {
 ##' @return vector of sample sizes, NA if n>N
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for n.hypergeo - checked
 ##' n.hypergeo(0.95, N=100, d=1, se = 0.95)
 ##' n.hypergeo(sep=0.95, N=c(100, 200, 500, 1000, 10000), d=ceiling(0.01*c(100, 200, 500, 1000, 10000)))
@@ -307,21 +309,21 @@ n.hypergeo<- function(sep, N, d, se = 1) {
 }
 
 
-##' Freedom sample size 
-##' @description Calculates sample size for demonstrating freedom or 
-##'   detecting disease using the appropriate method, depending on 
-##'   whether or not N provided (hypergeometric if N provided, binomial otherwise), 
-##'   assuming imperfect test sensitivity, perfect test specificity 
+##' Freedom sample size
+##' @description Calculates sample size for demonstrating freedom or
+##'   detecting disease using the appropriate method, depending on
+##'   whether or not N provided (hypergeometric if N provided, binomial otherwise),
+##'   assuming imperfect test sensitivity, perfect test specificity
 ##'   and representative sampling
 ##' @param N population size, default = NA (unknown) (scalar or vector of same length as sep)
 ##' @param sep desired population sensitivity (scalar or vector)
-##' @param pstar specified design prevalence as proportion or integer 
+##' @param pstar specified design prevalence as proportion or integer
 ##'   (scalar or vector of same length as sep)
 ##' @param se unit sensitivity (scalar or vector of same length as sep)
 ##' @return vector of sample sizes, NA if N is specified and n>N
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for n.freedom - checked
 ##' n.freedom(NA, sep=0.95, pstar=0.01, se=1)
 ##' n.freedom(500, sep=0.95, pstar=0.01, se=1)
@@ -354,24 +356,24 @@ n.freedom<- function(N=NA, sep=0.95, pstar,se=1) {
 
 
 ##' 2-stage freedom sample size
-##' @description Calculates sample sizes for a 2-stage representative survey 
+##' @description Calculates sample sizes for a 2-stage representative survey
 ##'   (sampling of clusters and units within clusters) for disease freedom or detection,
 ##'   assuming imperfect test sensitivity, perfect test specificity and representative sampling
 ##' @param H population size = number of clusters or NA if not known, default = NA
-##' @param N population sizes for clusters, default = NA, scalar or 
+##' @param N population sizes for clusters, default = NA, scalar or
 ##'   vector of population sizes for clusters
 ##' @param sep.sys desired population sensitivity (scalar)
 ##' @param sep.c desired cluster-level sensitivity (scalar)
-##' @param pstar.c specified cluster-level design prevalence as 
-##'   proportion or integer (scalar) 
-##' @param pstar.u specified population-level design prevalence as 
+##' @param pstar.c specified cluster-level design prevalence as
+##'   proportion or integer (scalar)
+##' @param pstar.u specified population-level design prevalence as
 ##'   proportion or integer (scalar)
 ##' @param se unit sensitivity (scalar)
-##' @return a list of 2 elements, the number of clusters to sample and a vector of 
+##' @return a list of 2 elements, the number of clusters to sample and a vector of
 ##'   sample sizes per cluster
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples of n.2stage - checked
 ##' n.2stage(NA, NA, 0.95, 0.5, 0.01, 0.1, 0.95)
 ##' n.2stage(500, NA, 0.95, 0.5, 10, 0.1, 0.95)
@@ -394,7 +396,7 @@ n.2stage<- function(H=NA, N=NA, sep.sys=0.95, sep.c, pstar.c, pstar.u, se=1) {
 
 ##' Design prevalence back-calculation
 ##' @description Calculates design prevalence required for given sample size and
-##'   desired population-level sensitivity, assuming 
+##'   desired population-level sensitivity, assuming
 ##'   imperfect test sensitivity, perfect test specificity and
 ##'   representative sampling
 ##' @param N populaton size if known (scalar or vector of same length as n)
@@ -404,7 +406,7 @@ n.2stage<- function(H=NA, N=NA, sep.sys=0.95, sep.c, pstar.c, pstar.u, se=1) {
 ##' @return vector of design prevalence values
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples of pstar.calc- checked
 ##' pstar.calc(NA, 280, 0.95, 0.98)
 ##' pstar.calc(500, 250, sep=0.95, se=1)
@@ -440,18 +442,18 @@ pstar.calc<- function(N=NA, n, sep, se) {
 # n.pfree
 
 ##' Equilibrium probability of freedom
-##' @description Calculates equilibrium probability of disease freedom and 
+##' @description Calculates equilibrium probability of disease freedom and
 ##'   equilibrium prior probability of freedom, after discounting for
 ##'   probability of introduction
 ##' @param sep population sensitivity for time period (scalar or
 ##'   vector)
 ##' @param p.intro probability of introduction for time period (scalar
 ##'   or vector of same length as sep)
-##' @return a list of 2 vectors, equilibrium posterior probability of freedom 
+##' @return a list of 2 vectors, equilibrium posterior probability of freedom
 ##'   and equilibrium prior (discounted) probability of freedom
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples of pfree.equ
 ##' pfree.equ(runif(10, 0.4, 0.6), 0.01)
 ##' pfree.equ(0.8, 0.05)
@@ -465,16 +467,16 @@ pfree.equ<- function(sep, p.intro) {
 
 ##' Discounted prior probability of freedom
 ##' @description Calculates the discounted prior probability of disease freedom,
-##'   after adjusting for the probability of disease exceeding the 
+##'   after adjusting for the probability of disease exceeding the
 ##'   design prevalence during the time period of the surveillance data being analysed
 ##' @param prior prior probability of freedom before surveillance
-##' @param p.intro probability of introduction 
-##'   (or of prevalence exceeding the design prevalence) during the time period 
+##' @param p.intro probability of introduction
+##'   (or of prevalence exceeding the design prevalence) during the time period
 ##'   (scalar or vector equal length to prior)
 ##' @return vector of discounted prior probabilities of freedom
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for disc.prior
 ##' disc.prior(0.5, 0.01)
 ##' disc.prior(0.95, c(0.001, 0.005, 0.01, 0.02, 0.05))
@@ -486,7 +488,7 @@ disc.prior<- function(prior, p.intro) {
 
 
 ##' Probability of freedom for single time period
-##' @description Calculates the posterior probability (confidence) of disease 
+##' @description Calculates the posterior probability (confidence) of disease
 ##'   freedom (negative predictive value) for a single time period
 ##' @param sep population sensitivity for time period (scalar or
 ##'   vector)
@@ -498,7 +500,7 @@ disc.prior<- function(prior, p.intro) {
 ##' prior, pfree, pfree.equ and prior.equ
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for pfree.1
 ##' pfree.1(0.8, 0.01, 0.5)
 ##' pfree.1(0.6, c(0.001, 0.005, 0.01, 0.02, 0.05), 0.5)
@@ -523,7 +525,7 @@ pfree.1<- function(sep, p.intro, prior=0.5) {
 
 
 ##' Probability of freedom over time
-##' @description Calculates the probability (confidence) of disease freedom for 
+##' @description Calculates the probability (confidence) of disease freedom for
 ##' given prior, sep and p.intro over 1 or more time periods
 ##' @param sep population sensitivity for each time period (vector)
 ##' @param p.intro probability of introduction for each time period (scalar
@@ -534,7 +536,7 @@ pfree.1<- function(sep, p.intro, prior=0.5) {
 ##'   and equilibrium prior
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for pfree.calc
 ##' pfree.calc(0.8, 0.01, 0.5)
 ##' pfree.calc(rep(0.6,24), 0.01, 0.5)
@@ -566,14 +568,14 @@ pfree.calc<- function(sep, p.intro, prior=0.5) {
 
 
 ##' Population sensitivity to achieve desired (posterior) probability of freedom
-##' @description Calculates the population sensitivity required to achieve a 
+##' @description Calculates the population sensitivity required to achieve a
 ##'   given value for probability of disease freedom
 ##' @param prior prior probability of freedom before surveillance (scalar or vector)
 ##' @param pfree desired probability of freedom (scalar or vector)
 ##' @return a vector of population-level sensitivities
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples of sep.pfree
 ##' sep.pfree(0.5, 0.95)
 ##' sep.pfree(c(0.5, 0.6, 0.7, 0.8, 0.9, 0.95), 0.99)
@@ -585,14 +587,14 @@ sep.pfree<- function(prior, pfree) {
 
 
 ##' Population sensitivity to achieve desired prior probability of freedom
-##' @description Calculates the population sensitivity required to achieve a 
+##' @description Calculates the population sensitivity required to achieve a
 ##'   given value for the prior (discounted) probability of disease freedom
 ##' @param prior prior probability of freedom before surveillance (scalar or vector)
 ##' @param p.intro probability of introduction for time period (scalar or vector equal length to sep)
 ##' @return a vector of population-level sensitivities
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples of sep.prior
 ##' sep.prior(0.95, 0.01)
 ##' sep.prior(c(0.9, 0.95, 0.98, 0.99), 0.01)
@@ -604,7 +606,7 @@ sep.prior<- function(prior, p.intro) {
 
 
 ##' Sample size to achieve desired (posterior) probability of freedom
-##' @description Calculates the sample size required to achieve a 
+##' @description Calculates the sample size required to achieve a
 ##'   given value for probability of disease freedom
 ##' @param pfree desired probability of freedom (scalar or vector)
 ##' @param prior prior probability of freedom before surveillance (scalar
@@ -617,19 +619,22 @@ sep.prior<- function(prior, p.intro) {
 ##' or vector of same length as pfree)
 ##' @param N population size (scalar
 ##' or vector of same length as pfree)
-##' @return vector of sample sizes
+##' @return a list of 3 elements, the first a vector of sample sizes
+##' and the second a corresponding vector of population sensitivity values
+##' and the third a vector of adjusted priors
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for n.pfree
 ##' n.pfree(0.95, 0.5, 0.01, 0.05, 0.9)
 ##' n.pfree(0.95, 0.5, 0.01, 0.05, 0.9, N=300)
 ##' n.pfree(pfree = c(0.9, 0.95, 0.98, 0.99), prior = 0.7, 0.01, 0.01, 0.8, 1000)
 ##' n.pfree(0.95, 0.7, 0.01, 0.1, 0.96)
 n.pfree<- function(pfree, prior, p.intro, pstar, se, N = NA) {
-  sep<- sep.pfree(prior, pfree)
+  adj.prior<- disc.prior(prior, p.intro)
+  sep<- sep.pfree(adj.prior, pfree)
   n<- n.freedom(N, sep, pstar, se)
-  return(n)
+  return(list(n, sep, adj.prior))
 }
 
 
@@ -642,13 +647,13 @@ n.pfree<- function(pfree, prior, p.intro, pstar, se, N = NA) {
 # sp.parallel
 
 ##' Sensitivity of tests in series
-##' @description Calculates the combined sensitivity for multiple tests 
+##' @description Calculates the combined sensitivity for multiple tests
 ##'   interpreted in series (assuming independence)
 ##' @param se vector of unit sensitivity values
 ##' @return scalar of combined sensitivity, assuming independence
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for se.series
 ##' se.series(c(0.99, 0.95, 0.8))
 se.series<- function(se) {
@@ -658,13 +663,13 @@ se.series<- function(se) {
 
 
 ##' Sensitivity of tests in parallel
-##' @description Calculates the combined sensitivity for multiple tests 
+##' @description Calculates the combined sensitivity for multiple tests
 ##'   interpreted in parallel (assuming independence)
 ##' @param se vector of unit sensitivity values
 ##' @return scalar of combined sensitivity, assuming independence
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for se.parallel
 ##' se.parallel(c(0.99, 0.95, 0.8))
 se.parallel<- function(se) {
@@ -673,13 +678,13 @@ se.parallel<- function(se) {
 }
 
 ##' Specficity of tests in series
-##' @description Calculates the combined specificity for multiple tests 
+##' @description Calculates the combined specificity for multiple tests
 ##'   interpreted in series (assuming independence)
 ##' @param sp vector of unit specificity values
 ##' @return scalar of combined specificity, assuming independence
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for sp.series
 ##' sp.series(c(0.99, 0.95, 0.8))
 sp.series<- function(sp) {
@@ -689,13 +694,13 @@ sp.series<- function(sp) {
 
 
 ##' Specificity of tests in parallel
-##' @description Calculates the combined specificity for multiple tests 
+##' @description Calculates the combined specificity for multiple tests
 ##'   interpreted in parallel (assuming independence)
 ##' @param sp vector of unit specificity values
 ##' @return scalar of combined specificity, assuming independence
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for sp.parallel
 ##' sp.parallel(c(0.99, 0.95, 0.8))
 sp.parallel<- function(sp) {
@@ -723,7 +728,7 @@ sp.parallel<- function(sp) {
 ##'   values
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for sep.pooled
 ##' sep.pooled(60, 5, 0.01, 1, 1)
 ##' sep.pooled(4, 10, 0.1, 0.9, 1)
@@ -737,7 +742,7 @@ sep.pooled<- function(r, k, pstar, pse, psp=1) {
 
 
 ##' Sample size for pooled testing for freedom
-##' @description Calculates sample size to achieve desired 
+##' @description Calculates sample size to achieve desired
 ##'   population-level sensitivity, assuming pooled sampling
 ##'   and allowing for imperfect sensitivity and specificity of the pooled test
 ##' @param sep desired population sensitivity (scalar or vector)
@@ -748,7 +753,7 @@ sep.pooled<- function(r, k, pstar, pse, psp=1) {
 ##' @return vector of sample sizes
 ##' @keywords methods
 ##' @export
-##' @examples 
+##' @examples
 ##' # examples for n.pooled
 ##' n.pooled(0.95, 5, 0.01, 1, 1)
 ##' n.pooled(0.95, 10, 0.1, 0.9, 1)
